options(
  #
  # McDavid
  McDavid.model = 'exact',
  McDavid.method = 'vb',
  McDavid.max.cells = 10,
  McDavid.save.output = FALSE,
  #
  # Windram
  Windram.model = 'exact-sizes',
  # Windram.model = 'lowrank-sizes',
  # Windram.method = 'vb',
  Windram.method = 'sample',
  Windram.max.genes = 10,
  Windram.max.cells = 10,
  Windram.save.output = FALSE,
  #
  # Shalek
  Shalek.model = 'lowrank',
  Shalek.method = 'vb',
  Shalek.max.genes = 33,
  Shalek.max.cells = 77,
  Shalek.save.output = FALSE)
